==> zio-aws-networkmanager_3-5.17.154.1-sources.jar: zio/aws/networkmanager/model/CreateLinkResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateLinkResponse(
    link: Option[zio.aws.networkmanager.model.Link] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse = {
    import CreateLinkResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
      .builder()
      .optionallyWith(link.map(value => value.buildAwsValue()))(_.link)
      .build()
  }
  def asReadOnly: zio.aws.networkmanager.model.CreateLinkResponse.ReadOnly =
    zio.aws.networkmanager.model.CreateLinkResponse.wrap(buildAwsValue())
}
object CreateLinkResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.CreateLinkResponse =
      zio.aws.networkmanager.model
        .CreateLinkResponse(link.map(value => value.asEditable))
    def link: Option[zio.aws.networkmanager.model.Link.ReadOnly]
    def getLink
        : ZIO[Any, AwsError, zio.aws.networkmanager.model.Link.ReadOnly] =
      AwsError.unwrapOptionField("link", link)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
  ) extends zio.aws.networkmanager.model.CreateLinkResponse.ReadOnly {
    override val link: Option[zio.aws.networkmanager.model.Link.ReadOnly] =
      scala
        .Option(impl.link())
        .map(value => zio.aws.networkmanager.model.Link.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
  ): zio.aws.networkmanager.model.CreateLinkResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-networkmanager_3-5.17.295.9-sources.jar: zio/aws/networkmanager/model/CreateLinkResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateLinkResponse(
    link: Optional[zio.aws.networkmanager.model.Link] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse = {
    import CreateLinkResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
      .builder()
      .optionallyWith(link.map(value => value.buildAwsValue()))(_.link)
      .build()
  }
  def asReadOnly: zio.aws.networkmanager.model.CreateLinkResponse.ReadOnly =
    zio.aws.networkmanager.model.CreateLinkResponse.wrap(buildAwsValue())
}
object CreateLinkResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.CreateLinkResponse =
      zio.aws.networkmanager.model
        .CreateLinkResponse(link.map(value => value.asEditable))
    def link: Optional[zio.aws.networkmanager.model.Link.ReadOnly]
    def getLink
        : ZIO[Any, AwsError, zio.aws.networkmanager.model.Link.ReadOnly] =
      AwsError.unwrapOptionField("link", link)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
  ) extends zio.aws.networkmanager.model.CreateLinkResponse.ReadOnly {
    override val link: Optional[zio.aws.networkmanager.model.Link.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.link())
        .map(value => zio.aws.networkmanager.model.Link.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateLinkResponse
  ): zio.aws.networkmanager.model.CreateLinkResponse.ReadOnly = new Wrapper(
    impl
  )
}
